/*++++++++++++++
.IDENTIFICATION ucac.h
.LANGUAGE       C
.AUTHOR         Francois Ochsenbein [CDS]
.ENVIRONMENT    USNO-A2.0 Catalogue
.KEYWORDS       CDS Catalogue Server
.VERSION  1.0   01-Mar-1997
.VERSION  2.0   13-Oct-2003: UCAC2
.COMMENTS       Structures & Definitions concerning the UCAC2 Catalog
---------------*/

#ifndef UCAC2_DEF
#define UCAC2_DEF	0
#ifndef _ARG
#ifdef __STDC__
#define _ARG(A)	A    /* ANSI */
#else
#define _ARG(A)	()  /* non-ANSI */
#define const
#endif
#endif

/*===========================================================================
		Structures 
 *===========================================================================*/

typedef struct {
    short zone ;		/* Original zone number	(0.5dg)	*/
    unsigned char no, nc ;	/* # Observations, Catalogs	*/
    long id, ra, sd ;		/* RA and South Polar Dist, mas	*/
    short sra, ssd, spos;	/* Sigmas on ra, sd and pos mas	*/
    short cflag;		/* Catalog flags 		*/
    long epRA, epDE ;		/* Epoch in myr (0.001 yr)	*/
    int pmra, pmsd, pmtot ;	/* Proper motions, 0.1mas/yr	*/
    short spmra, spmsd ;	/* Sigmas on pm's, 0.1mas/yr	*/
    short qpmra, qpmsd ;	/* Qualities (goodness) on pm's	*/
    short mag ;			/* UCAC2  magnitude (mmag)	*/
    short Jmag, Hmag, Kmag;	/* 2MASS mmag (NULL=-32768)	*/
    long id2M;			/* 2MASS Identifier 		*/
    short ph2M, cc2M;		/* 2MASS Flags			*/
    long rho, theta ;		/* Distance from center (mas)	*/
    long xy[2] ;		/* Values of proj. x,y  (mas)	*/
} UCAC2rec ;
#define NULLxy	(-999999999)	/* Non-computed values for xy	*/

/*===========================================================================
		Prototypes Declarations
 *===========================================================================*/
 
int   ucac2_init   _ARG((char *UCACroot)) ;
char *ucac2_araw   _ARG((UCAC2rec *pr));
char *ucac2_a      _ARG((UCAC2rec *pr, int opt)) ;
			/* Option: 1 in sexa, 2=ID, 4=Epoch */
char *ucac2_head   _ARG((int opt)) ;
long  ucac2_seek   _ARG((long ra, long sd)) ; 	/* Position in mas */
long  ucac2_search _ARG((long ra[2], long sd[2], int (*digest_routine)())) ;
int   ucac2_set    _ARG((long id)) ;
int   ucac2_zopen  _ARG((int zone)) ;
int   ucac2_get    _ARG((long id, UCAC2rec *rec)) ;
int   ucac2_read   _ARG((UCAC2rec *rec)) ;
int   ucac2_stop   _ARG((int stopping_flag)) ;	/* 0=not, 1=eoZ, 2=eoChunk */
#endif
